@@ -141,6 +141,9 @@ x$plotOptions$curveShape -> curveShape
 x$plotOptions$curveScale -> curveScale
 x$plotOptions$curvePivotShape -> curvePivotShape
 x$plotOptions$label.scale -> label.scale
+x$plotOptions$label.scale.equal -> label.scale.equal
+x$plotOptions$label.fill.vertical -> label.fill.vertical
+x$plotOptions$label.fill.horizontal -> label.fill.horizontal
 x$plotOptions$label.norm -> label.norm
 x$plotOptions$label.prop -> label.prop
 x$plotOptions$overlay -> overlay
@@ -987,6 +990,7 @@ x$plotOptions$legend.mode -> legend.mode
     
     if (is.null(label.cex)) label.cex <- pmax(1,vsize)
     # Rescale labels:
+
     if (label.scale)
     {
       VWidths <- sapply(mapply(Cent2Edge,cex=vsize,cex2=vsize2,shape=shape,MoreArgs=list(x=0,y=0,r=pi/2,polygonList=polygonList, noPar = noPar),SIMPLIFY=FALSE),'[',1) * 2
@@ -994,8 +998,16 @@ x$plotOptions$legend.mode -> legend.mode
       LWidths <- pmax(sapply(label.cex,function(x)strwidth(label.norm,cex=x)),mapply(strwidth, s=labels, cex=label.cex))
       LHeights <- pmax(sapply(label.cex,function(x)strheight(label.norm,cex=x)),mapply(strheight, s=labels, cex=label.cex))
       
-      label.cex <- label.cex * label.prop * pmin(VWidths/LWidths,VHeights/LHeights)
+      label.cex <- label.cex * label.prop * pmin((VWidths*label.fill.horizontal)/LWidths,(VHeights*label.fill.vertical)/LHeights)
       #           label.cex[nchar(labels)>1]=label.cex[nchar(labels)>1]*2/nchar(labels[nchar(labels)>1],"width")
+      
+      # Equalize:
+      if (!identical(label.scale.equal,FALSE)){
+        if (isTRUE(label.scale.equal)){
+          label.scale.equal <- rep(1,length(label.cex))
+        }
+        label.cex[] <- ave(label.cex,label.scale.equal,FUN=min)
+      }
     }
     
     # Plot labels:
